@@ -1,12 +1,11 @@
 package Dist::Zilla::PluginBundle::Author::Plicease;
 
 use Moose;
-use v5.10;
 use Dist::Zilla;
 use PerlX::Maybe qw( maybe );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.34'; # VERSION
+our $VERSION = '1.40'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -19,7 +18,22 @@ sub configure
 {
   my($self) = @_;
 
+  # undocumented for a reason: sometimes I need to release on
+  # a different platform that where I do testing, (eg. MSWin32
+  # only modules, where Dist::Zilla is frequently not working
+  # right).
+  if($self->payload->{non_native_release})
+  {
+    eval q{
+      no warnings 'redefine';
+      use Dist::Zilla::Role::BuildPL;
+      sub Dist::Zilla::Role::BuildPL::build {};
+      sub Dist::Zilla::Role::BuildPL::test {};
+    };
+  }
+
   $self->add_plugins(
+    'Author::Plicease::FiveEight',
     'GatherDir',
     [ PruneCruft => { except => '.travis.yml' } ],
     'ManifestSkip',
@@ -29,7 +43,7 @@ sub configure
     'ShareDir',
   );
   
-  my $installer = $self->payload->{installer} // 'MakeMaker';
+  my $installer = $self->payload->{installer} || 'MakeMaker';
   if($installer eq 'Alien')
   {
     my %args = 
@@ -38,6 +52,13 @@ sub configure
       grep /^alien_/, keys %{ $self->payload };
     $self->add_plugins([ Alien => \%args ]);
   }
+  elsif($installer eq 'ModuleBuild')
+  {
+    my %args = 
+      map { $_ => $self->payload->{$_} }
+      grep /^mb_/, keys %{ $self->payload };
+    $self->add_plugins([ ModuleBuild => \%args ]);
+  }
   else
   {
     $self->add_plugins($installer);
@@ -64,9 +85,12 @@ sub configure
 
   ));
 
-  $self->add_bundle('Git' => {
-    allow_dirty => [ qw( dist.ini Changes README.md ) ],
-  });
+  unless($] < 5.010000)
+  {
+    $self->add_bundle('Git' => {
+      allow_dirty => [ qw( dist.ini Changes README.md ) ],
+    });
+  }
 
   $self->add_plugins([
     AutoMetaResources => {
@@ -76,8 +100,17 @@ sub configure
     }
   ]);
 
-  $self->add_plugins('Author::Plicease::Tests')
-    if $self->payload->{release_tests};
+  if($self->payload->{release_tests})
+  {
+    if($self->payload->{release_tests_skip})
+    {
+      $self->add_plugins([ 'Author::Plicease::Tests' => { skip => $self->payload->{release_tests_skip} }])
+    }
+    else
+    {
+      $self->add_plugins('Author::Plicease::Tests')
+    }
+  }
     
   $self->add_plugins(qw(
 
@@ -108,7 +141,7 @@ sub configure
   
   $self->add_plugins([
     'Author::Plicease::MarkDownCleanup' => {
-      travis_status => int($self->payload->{travis_status}//0),
+      travis_status => int(defined $self->payload->{travis_status} ? $self->payload->{travis_status} : 0),
     },
   ]);
   
@@ -131,7 +164,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.34
+version 1.40
 
 =head1 SYNOPSIS
 
@@ -206,6 +239,10 @@ If installer is L<Alien|Dist::Zilla::Plugin::Alien>, then any options
 with the alien_ prefix will be passed to L<Alien|Dist::Zilla::Plugin::Alien>
 (minus the alien_ prefix).
 
+If installer is L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild>, then any
+options with the mb_ prefix will be passed to L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild>
+(including the mb_ prefix).
+
 =head2 readme_from
 
 Which file to pull from for the Readme (must be POD format).  If not 
@@ -215,10 +252,20 @@ specified, then the main module will be used.
 
 If set to true, then include release tests when building.
 
+=head2 release_tests_skip
+
+Passed into the L<Author::Plicease::Tests|Dist::Zilla::Plugin::Author::Plicease::Tests>
+if C<release_tests> is true.
+
 =head2 travis_status
 
 if set to true, then include a link to the travis build page in the readme.
 
+=head2 mb_class
+
+if builder = ModuleBuild, this is the mb_class passed into the [ModuleBuild]
+plugin.
+
 =head1 SEE ALSO
 
 L<Author::Plicease::Init|Dist::Zilla::Plugin::Author::Plicease::Init>,
